@@ -1,10 +1,8 @@
 #!/usr/bin/perl -w
 
-use utf8;
-
 package HTML::Widgets::NavMenu;
 
-our $VERSION = '0.1.15_00';
+our $VERSION = '0.2.0';
 
 package HTML::Widgets::NavMenu::Error;
 
